@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: LGPL-2.1-or-later
 // Copyright (c) 2012-2014 Monty Program Ab
-// Copyright (c) 2015-2024 MariaDB Corporation Ab
+// Copyright (c) 2015-2025 MariaDB Corporation Ab
 package org.mariadb.jdbc.client.column;
 
 import java.sql.*;
@@ -71,7 +71,12 @@ public class UnsignedSmallIntColumn extends ColumnDefinitionPacket implements Co
   }
 
   public int getColumnType(final Configuration conf) {
-    return Types.INTEGER;
+    boolean resultSetMetaDataUnsignedCompatibility =
+        Boolean.parseBoolean(
+            conf.nonMappedOptions().getProperty("resultSetMetaDataUnsignedCompatibility", "false"));
+    // compatibility option to ensure compatibility
+    // to be removed in 4.0
+    return resultSetMetaDataUnsignedCompatibility ? Types.INTEGER : Types.SMALLINT;
   }
 
   public String getColumnTypeName(final Configuration conf) {
