@@ -61,9 +61,6 @@ public class PooledConnectionTest extends Common {
 
   @Test
   public void testPoolFailover() throws Exception {
-    Assumptions.assumeTrue(
-        !"skysql".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
-
     Configuration conf = Configuration.parse(mDefUrl);
     HostAddress hostAddress = conf.addresses().get(0);
     try {
@@ -97,12 +94,7 @@ public class PooledConnectionTest extends Common {
 
   @Test
   public void testPoolKillConnection() throws Exception {
-    Assumptions.assumeTrue(
-        !"maxscale".equals(System.getenv("srv"))
-            && !"skysql".equals(System.getenv("srv"))
-            && !"skysql-ha".equals(System.getenv("srv"))
-            && !"galera".equals(System.getenv("srv"))
-            && !isXpand());
+    Assumptions.assumeTrue(!isMaxscale());
 
     File.createTempFile("log", ".tmp");
 
@@ -127,12 +119,6 @@ public class PooledConnectionTest extends Common {
 
   @Test
   public void testPooledConnectionException() throws Exception {
-    Assumptions.assumeTrue(
-        !"skysql".equals(System.getenv("srv"))
-            && !"skysql-ha".equals(System.getenv("srv"))
-            && !"galera".equals(System.getenv("srv"))
-            && !isXpand());
-
     ConnectionPoolDataSource ds = new MariaDbDataSource(mDefUrl);
     PooledConnection pc = null;
     try {
@@ -159,8 +145,6 @@ public class PooledConnectionTest extends Common {
 
   @Test
   public void testPooledConnectionException2() throws Exception {
-    Assumptions.assumeTrue(
-        !"maxscale".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
     try (Pool pool = Pools.retrievePool(Configuration.parse(mDefUrl + "&maxPoolSize=2"))) {
       MariaDbInnerPoolConnection pooledConnection = pool.getPoolConnection();
       org.mariadb.jdbc.Connection con = pooledConnection.getConnection();
@@ -178,46 +162,52 @@ public class PooledConnectionTest extends Common {
 
   @Test
   public void testPooledConnectionStatementError() throws Exception {
-    Assumptions.assumeTrue(
-        !"maxscale".equals(System.getenv("srv")) && !"skysql-ha".equals(System.getenv("srv")));
+    Assumptions.assumeTrue(!isMaxscale());
     Statement stmt = sharedConn.createStatement();
-    try {
-      stmt.execute("DROP USER 'dsUser'");
-    } catch (SQLException e) {
-      // eat
-    }
+    stmt.execute("DROP USER IF EXISTS 'StatementErrorUser'" + getHostSuffix());
 
     if (minVersion(8, 0, 0)) {
       if (isMariaDBServer() || minVersion(8, 4, 0)) {
-        stmt.execute("CREATE USER 'dsUser'@'%' IDENTIFIED BY 'MySup8%rPassw@ord'");
+        stmt.execute(
+            "CREATE USER 'StatementErrorUser'"
+                + getHostSuffix()
+                + " IDENTIFIED BY"
+                + " 'MySup8%rPassw@ord'");
       } else {
         stmt.execute(
-            "CREATE USER 'dsUser'@'%' IDENTIFIED WITH mysql_native_password BY"
-                + " 'MySup8%rPassw@ord'");
+            "CREATE USER 'StatementErrorUser'"
+                + getHostSuffix()
+                + " IDENTIFIED WITH"
+                + " mysql_native_password BY 'MySup8%rPassw@ord'");
       }
-      stmt.execute("GRANT SELECT ON " + sharedConn.getCatalog() + ".* TO 'dsUser'@'%'");
+      stmt.execute("GRANT ALL ON *.* TO 'StatementErrorUser'" + getHostSuffix());
     } else {
-      stmt.execute("CREATE USER 'dsUser'@'%'");
+      stmt.execute("CREATE USER 'StatementErrorUser'" + getHostSuffix());
       stmt.execute(
-          "GRANT SELECT ON "
-              + sharedConn.getCatalog()
-              + ".* TO 'dsUser'@'%' IDENTIFIED BY 'MySup8%rPassw@ord'");
+          "GRANT ALL ON *.* TO 'StatementErrorUser'"
+              + getHostSuffix()
+              + " IDENTIFIED BY"
+              + " 'MySup8%rPassw@ord'");
     }
     stmt.execute("FLUSH PRIVILEGES");
 
-    ConnectionPoolDataSource ds = new MariaDbDataSource(mDefUrl);
-    PooledConnection pc = ds.getPooledConnection("dsUser", "MySup8%rPassw@ord");
-    MyEventListener listener = new MyEventListener();
-    pc.addStatementEventListener(listener);
-    Connection connection = pc.getConnection();
-    try (PreparedStatement ps = connection.prepareStatement("SELECT ?")) {
-      ps.execute();
-      fail("should never get there");
-    } catch (Exception e) {
-      assertTrue(listener.statementErrorOccurred);
+    try {
+      ConnectionPoolDataSource ds = new MariaDbDataSource(mDefUrl);
+      PooledConnection pc = ds.getPooledConnection("StatementErrorUser", "MySup8%rPassw@ord");
+      MyEventListener listener = new MyEventListener();
+      pc.addStatementEventListener(listener);
+      Connection connection = pc.getConnection();
+      try (PreparedStatement ps = connection.prepareStatement("SELECT ?")) {
+        ps.execute();
+        fail("should never get there");
+      } catch (Exception e) {
+        assertTrue(listener.statementErrorOccurred);
+      }
+      assertTrue(listener.statementClosed);
+      pc.close();
+    } finally {
+      stmt.execute("DROP USER IF EXISTS 'StatementErrorUser'" + getHostSuffix());
     }
-    assertTrue(listener.statementClosed);
-    pc.close();
   }
 
   public static class MyEventListener implements ConnectionEventListener, StatementEventListener {
