@@ -971,17 +971,28 @@ public class IntCodecTest extends CommonCodecTest {
     assertEquals("java.lang.Long", meta.getColumnClassName(1));
     assertEquals("t1alias", meta.getColumnLabel(1));
     assertEquals("t1", meta.getColumnName(1));
-    assertEquals(Types.BIGINT, meta.getColumnType(1));
+    assertEquals(Types.INTEGER, meta.getColumnType(1));
     assertEquals(4, meta.getColumnCount());
     assertEquals(10, meta.getPrecision(1));
     assertEquals(0, meta.getScale(1));
     assertEquals("", meta.getSchemaName(1));
     assertEquals(10, meta.getColumnDisplaySize(1));
 
-    // https://jira.mariadb.org/browse/XPT-276
-    if (!isXpand()) {
-      assertEquals(10, meta.getColumnDisplaySize(1));
-      assertEquals(10, meta.getPrecision(1));
+    assertEquals(10, meta.getColumnDisplaySize(1));
+    assertEquals(10, meta.getPrecision(1));
+
+    try (org.mariadb.jdbc.Connection conn =
+        createCon("&resultSetMetaDataUnsignedCompatibility=true")) {
+      Statement stmt = conn.createStatement();
+      stmt.execute("START TRANSACTION"); // if MAXSCALE ensure using WRITER
+      rs =
+          stmt.executeQuery(
+              "select t1 as t1alias, t2 as t2alias, t3 as t3alias, t4 as t4alias from"
+                  + " IntCodecUnsigned");
+      assertTrue(rs.next());
+      stmt.execute("COMMIT");
+      meta = rs.getMetaData();
+      assertEquals(Types.BIGINT, meta.getColumnType(1));
     }
   }
 
